#!/usr/bin/env python
# coding: utf-8

# In[10]:


import pandas as pd
from matplotlib import pyplot as plt


# In[11]:


def xtract(googleSheetId,worksheetName):
        URL = 'https://docs.google.com/spreadsheets/d/{0}/gviz/tq?tqx=out:csv&sheet={1}'.format(googleSheetId,worksheetName)
        df = pd.read_csv(URL)
        print(df) 
        l = []
        print(df.columns)
        print("select the required x,y for plotting")
        x=input()
        y=input()
        l.append(x)
        l.append(y)
        x = list(df[l[0]].values)
        y = list(df[l[1]].values)

        plt.plot(x,y)
        
        l.clear()
        


# In[ ]:





# In[ ]:





# In[ ]:





# In[ ]:







#!/usr/bin/env python
# coding: utf-8

# In[3]:


from setuptools import setup, find_packages
 
classifiers = [
 
  'Operating System :: OS Independent',
  'License :: OSI Approved :: MIT License',
  'Programming Language :: Python :: 3'
]
 
setup(
  name='googlesxtractor',
  version='0.0.1',
  description='google sheets data extractor',
  long_description=open('README.txt').read(),
  url='https://github.com/prasannareddy2999',  
  author='Lakshmi Prasanna Reddy',
  author_email='Prasannareddy3555@gmail.com',
  license='MIT', 
  classifiers=classifiers,
  keywords='data extractor', 
  packages=find_packages()
  
)


# In[ ]:




